ValidationConnector<K, I> class abstract

Defines relation between data and validation

Implementers

Constructors

ValidationConnector()

Properties

controller → ValidationController<K>?
Attached ValidationController controller
no setter
field → K
Field key for error message
no setter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

attach(ValidationController<K> controller) → void
Attach connector to the validation controller
detach() → void
Detach connector from the validation controller
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
validate() → String?
Validate current field value. Returns error message if current value is invalid
validateField() → void
Validates field, and pushes result to the ValidationController

Operators

operator ==(Object other) → bool
The equality operator.
inherited