AfterDateTimeValidator class

Validates if value is after defined DateTime

Inheritance

Constructors

AfterDateTimeValidator(DateTime dateTime, {String? fieldName, String? errorMessage, String formatter(DateTime)?})
AfterDateTimeValidator.withMessage(DateTime dateTime, String message)
const

Properties

dateTime → DateTime
final
formatter → String Function(DateTime)?
final
hashCode → int
The hash code for this object.
no setterinherited
ignoreNullable → bool
If validation can be invoked on null values.
finalinherited
message → String
Validation error message.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

call(DateTime? value) → String?
Invoke validation
inherited
isValid(DateTime? value) → bool
Validation function
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited