EqualToValidator<I> class

Checks if value is equal to provided value

Inheritance
Implementers

Constructors

EqualToValidator(I? equalTo, {String? fieldName, String? message})
const
EqualToValidator.withMessage(I? equalTo, String message)
const

Properties

equalTo → I?
final
hashCode → int
The hash code for this object.
no setterinherited
ignoreNullable → bool
If validation can be invoked on null values.
finalinherited
message → String
Validation error message.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

call(I? value) → String?
Invoke validation
inherited
isValid(I? value) → bool
Validation function
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited