LessThanValidator<I extends num> class

Check if field value less than a provided value

Inheritance

Constructors

LessThanValidator(I max, {String? fieldName, String? errorMessage})
const
LessThanValidator.withMessage(I max, String message)
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
ignoreNullable → bool
If validation can be invoked on null values.
finalinherited
max → I
final
message → String
Validation error message.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

call(I? value) → String?
Invoke validation
inherited
isValid(I? value) → bool
Validation function
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited