NotEmptyMapValidator<K, V> class

Validates if Map is not empty

Inheritance

Constructors

NotEmptyMapValidator({String? fieldName, String? message})
const
NotEmptyMapValidator.withMessage(String message)
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
ignoreNullable → bool
If validation can be invoked on null values.
finalinherited
message → String
Validation error message.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

call(Map<K, V>? value) → String?
Invoke validation
inherited
isValid(Map<K, V>? value) → bool
Validation function
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited