UriValidator class

Check if value is valid URI string

Inheritance

Constructors

UriValidator({String? path, String? host, String? scheme, int? port, String? fieldName, String? errorMessage})
const
UriValidator.withMessage({required String message, String? path, String? scheme, String? host, int? port})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
host → String?
final
ignoreNullable → bool
If validation can be invoked on null values.
finalinherited
message → String
Validation error message.
finalinherited
path → String?
final
port → int?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scheme → String?
final

Methods

call(String? value) → String?
Invoke validation
inherited
isValid(String? value) → bool
Validation function
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited