ValueErrorsProvider<K> class

Provides info about field validation

Implemented types

Constructors

ValueErrorsProvider(Iterable<K> fields, Iterable<String> value)
const

Properties

fields → Iterable<K>
Field keys
final
hasError → bool
If provider has an error messages
no setteroverride
hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → Iterable<String>
Current validation error values
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override